==> pygame-2.0.2.tar.gz: pygame-2.0.2/src_c/doc/music_doc.h <==
/* Auto generated file: with makeref.py .  Docs go in docs/reST/ref/ . */
#define DOC_PYGAMEMIXERMUSIC "pygame module for controlling streamed audio"
#define DOC_PYGAMEMIXERMUSICLOAD "load(filename) -> None\nload(fileobj, namehint="") -> None\nLoad a music file for playback"
#define DOC_PYGAMEMIXERMUSICUNLOAD "unload() -> None\nUnload the currently loaded music to free up resources"
#define DOC_PYGAMEMIXERMUSICPLAY "play(loops=0, start=0.0, fade_ms=0) -> None\nStart the playback of the music stream"
#define DOC_PYGAMEMIXERMUSICREWIND "rewind() -> None\nrestart music"
#define DOC_PYGAMEMIXERMUSICSTOP "stop() -> None\nstop the music playback"
#define DOC_PYGAMEMIXERMUSICPAUSE "pause() -> None\ntemporarily stop music playback"
#define DOC_PYGAMEMIXERMUSICUNPAUSE "unpause() -> None\nresume paused music"
#define DOC_PYGAMEMIXERMUSICFADEOUT "fadeout(time) -> None\nstop music playback after fading out"
#define DOC_PYGAMEMIXERMUSICSETVOLUME "set_volume(volume) -> None\nset the music volume"
#define DOC_PYGAMEMIXERMUSICGETVOLUME "get_volume() -> value\nget the music volume"
#define DOC_PYGAMEMIXERMUSICGETBUSY "get_busy() -> bool\ncheck if the music stream is playing"
#define DOC_PYGAMEMIXERMUSICSETPOS "set_pos(pos) -> None\nset position to play from"
#define DOC_PYGAMEMIXERMUSICGETPOS "get_pos() -> time\nget the music play time"
#define DOC_PYGAMEMIXERMUSICQUEUE "queue(filename) -> None\nqueue(fileobj, namehint="") -> None\nqueue a sound file to follow the current"
#define DOC_PYGAMEMIXERMUSICSETENDEVENT "set_endevent() -> None\nset_endevent(type) -> None\nhave the music send an event when playback stops"
#define DOC_PYGAMEMIXERMUSICGETENDEVENT "get_endevent() -> type\nget the event a channel sends when playback stops"


/* Docs in a comment... slightly easier to read. */

/*

pygame.mixer.music
pygame module for controlling streamed audio

pygame.mixer.music.load
 load(filename) -> None
 load(fileobj, namehint="") -> None
Load a music file for playback

pygame.mixer.music.unload
 unload() -> None
Unload the currently loaded music to free up resources

pygame.mixer.music.play
 play(loops=0, start=0.0, fade_ms=0) -> None
Start the playback of the music stream

pygame.mixer.music.rewind
 rewind() -> None
restart music

pygame.mixer.music.stop
 stop() -> None
stop the music playback

pygame.mixer.music.pause
 pause() -> None
temporarily stop music playback

pygame.mixer.music.unpause
 unpause() -> None
resume paused music

pygame.mixer.music.fadeout
 fadeout(time) -> None
stop music playback after fading out

pygame.mixer.music.set_volume
 set_volume(volume) -> None
set the music volume

pygame.mixer.music.get_volume
 get_volume() -> value
get the music volume

pygame.mixer.music.get_busy
 get_busy() -> bool
check if the music stream is playing

pygame.mixer.music.set_pos
 set_pos(pos) -> None
set position to play from

pygame.mixer.music.get_pos
 get_pos() -> time
get the music play time

pygame.mixer.music.queue
 queue(filename) -> None
 queue(fileobj, namehint="") -> None
queue a sound file to follow the current

pygame.mixer.music.set_endevent
 set_endevent() -> None
 set_endevent(type) -> None
have the music send an event when playback stops

pygame.mixer.music.get_endevent
 get_endevent() -> type
get the event a channel sends when playback stops

*/

==> pygame_2.6.1.orig.tar.gz: pygame-2.6.1/src_c/doc/music_doc.h <==
/* Auto generated file: with makeref.py .  Docs go in docs/reST/ref/ . */
#define DOC_PYGAMEMIXERMUSIC "pygame module for controlling streamed audio"
#define DOC_PYGAMEMIXERMUSICLOAD "load(filename) -> None\nload(fileobj, namehint="") -> None\nLoad a music file for playback"
#define DOC_PYGAMEMIXERMUSICUNLOAD "unload() -> None\nUnload the currently loaded music to free up resources"
#define DOC_PYGAMEMIXERMUSICPLAY "play(loops=0, start=0.0, fade_ms=0) -> None\nStart the playback of the music stream"
#define DOC_PYGAMEMIXERMUSICREWIND "rewind() -> None\nrestart music"
#define DOC_PYGAMEMIXERMUSICSTOP "stop() -> None\nstop the music playback"
#define DOC_PYGAMEMIXERMUSICPAUSE "pause() -> None\ntemporarily stop music playback"
#define DOC_PYGAMEMIXERMUSICUNPAUSE "unpause() -> None\nresume paused music"
#define DOC_PYGAMEMIXERMUSICFADEOUT "fadeout(time) -> None\nstop music playback after fading out"
#define DOC_PYGAMEMIXERMUSICSETVOLUME "set_volume(volume) -> None\nset the music volume"
#define DOC_PYGAMEMIXERMUSICGETVOLUME "get_volume() -> value\nget the music volume"
#define DOC_PYGAMEMIXERMUSICGETBUSY "get_busy() -> bool\ncheck if the music stream is playing"
#define DOC_PYGAMEMIXERMUSICSETPOS "set_pos(pos) -> None\nset position to play from"
#define DOC_PYGAMEMIXERMUSICGETPOS "get_pos() -> time\nget the music play time"
#define DOC_PYGAMEMIXERMUSICQUEUE "queue(filename) -> None\nqueue(fileobj, namehint="", loops=0) -> None\nqueue a sound file to follow the current"
#define DOC_PYGAMEMIXERMUSICSETENDEVENT "set_endevent() -> None\nset_endevent(type) -> None\nhave the music send an event when playback stops"
#define DOC_PYGAMEMIXERMUSICGETENDEVENT "get_endevent() -> type\nget the event a channel sends when playback stops"


/* Docs in a comment... slightly easier to read. */

/*

pygame.mixer.music
pygame module for controlling streamed audio

pygame.mixer.music.load
 load(filename) -> None
 load(fileobj, namehint="") -> None
Load a music file for playback

pygame.mixer.music.unload
 unload() -> None
Unload the currently loaded music to free up resources

pygame.mixer.music.play
 play(loops=0, start=0.0, fade_ms=0) -> None
Start the playback of the music stream

pygame.mixer.music.rewind
 rewind() -> None
restart music

pygame.mixer.music.stop
 stop() -> None
stop the music playback

pygame.mixer.music.pause
 pause() -> None
temporarily stop music playback

pygame.mixer.music.unpause
 unpause() -> None
resume paused music

pygame.mixer.music.fadeout
 fadeout(time) -> None
stop music playback after fading out

pygame.mixer.music.set_volume
 set_volume(volume) -> None
set the music volume

pygame.mixer.music.get_volume
 get_volume() -> value
get the music volume

pygame.mixer.music.get_busy
 get_busy() -> bool
check if the music stream is playing

pygame.mixer.music.set_pos
 set_pos(pos) -> None
set position to play from

pygame.mixer.music.get_pos
 get_pos() -> time
get the music play time

pygame.mixer.music.queue
 queue(filename) -> None
 queue(fileobj, namehint="", loops=0) -> None
queue a sound file to follow the current

pygame.mixer.music.set_endevent
 set_endevent() -> None
 set_endevent(type) -> None
have the music send an event when playback stops

pygame.mixer.music.get_endevent
 get_endevent() -> type
get the event a channel sends when playback stops

*/
